MolGrid object
==============

The class that creates and controls the grid of molecules. Allows for a more
advanced usage, like filtering the grid using external controls such as
slider widgets. See the notebooks for examples.

.. autoclass:: mols2grid.MolGrid
    :members: